EventResolver class abstract

Annotations
  • @Deprecated("Will be removed in the next major release.")

Constructors

EventResolver({required UIDriver driver, DebugLogger? logger})

Properties

driver UIDriver
final
hashCode int
The hash code for this object.
no setterinherited
logger DebugLogger?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveEvent(BuildContext context, dynamic eventData) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited