ThemePreprocessor class abstract

Implementers

Constructors

ThemePreprocessor({TokenizationCallback? customWidgetTokenizer, TokenizationCallback? overrideWidgetTokenizer})
const

Properties

customWidgetTokenizer TokenizationCallback?
final
hashCode int
The hash code for this object.
no setterinherited
overrideWidgetTokenizer TokenizationCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createToken(String widgetType, Map<String, dynamic> themeData) ThemeToken
Creates token for default cases
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tokenize(Map<String, dynamic> theme) DuitTheme
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited