UIDriver class abstract

Mixed-in types
Implementers

Constructors

UIDriver()

Properties

actionExecutor ↔ ActionExecutor
The executor of actions used by the UI driver.
getter/setter pair
buildContext → BuildContext
The build context associated with the UI driver.
no setterinherited
context ← BuildContext
Sets the current BuildContext for the delegate.
no getterinherited
controllersCount → int
Returns the number of currently attached UIElementControllers managed by this delegate.
no setterinherited
currentView → DuitView?
Get the current view being displayed.
no setterinherited
driverChannel ↔ MethodChannel?
getter/setter pair
eventResolver ↔ EventResolver
The script runner used by the UI driver.
getter/setter pair
eventStream → Stream<UIDriverEvent>
A stream of UIDriverEvents that this delegate manages or receives.
no setterinherited
externalEventHandler ↔ ExternalEventHandler?
The action executor used by the UI driver.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isModule ↔ bool
getter/setter pair
logger ↔ DebugLogger?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptRunner ↔ ScriptRunner?
The script runner used by the UI driver.
getter/setter pair
source → String
The source url of the UI driver.
final
transport ↔ Transport?
The transport used by the UI driver.
getter/setter pair
transportOptions → TransportOptions
The options for the transport used by the UI driver.
final

Methods

addExternalEventStream(Stream<Map<String, dynamic>> stream) → void
Registers an external stream of events to be handled by the delegate.
inherited
addUIDriverError(Object error, [StackTrace? stackTrace]) → void
Reports an error that occurred within the UI driver context to the delegate.
inherited
addUIDriverEvent(UIDriverEvent event) → void
Adds a UIDriverEvent to the event stream or processes it within the view capability delegate.
inherited
attachController(String id, UIElementController controller) → void
Attaches a UI element controller to the driver.
inherited
attachExternalHandler(UserDefinedHandlerKind type, UserDefinedEventHandler handle) → void
Registers an external handler for a given kind of user-defined action or event.
inherited
attachFocusNode(String nodeId, FocusNode node) → void
Attaches a FocusNode to the delegate, associating it with the provided nodeId.
inherited
build() → Widget?
Builds the UI.
connect({Map<String, dynamic>? initialRequestData, Map<String, dynamic>? staticContent}) → Stream<Map<String, dynamic>>
Establishes a connection to the server.
inherited
detachController(String id) → void
Detaches the UI element controller associated with the given id.
inherited
detachFocusNode(String nodeId) → void
inherited
dispose() → void
Disposes of the driver and releases any resources.
evalScript(String source) → Future<void>
Eval script source code
inherited
execScript(String functionName, {String? url, Map<String, dynamic>? meta, Map<String, dynamic>? body}) → Future<Map<String, dynamic>?>
Based on the name of the function, starts its execution.
inherited
execute(ServerAction action) → Future<void>
Executes the given ServerAction.
inherited
executeRemoteAction(ServerAction action, Map<String, dynamic> payload) → Future<Map<String, dynamic>?>
Executes a server action with the given payload and returns a server event.
inherited
focusInDirection(String nodeId, TraversalDirection direction) → bool
Moves the focus from the node identified by nodeId in the specified direction.
inherited
getController(String id) → UIElementController?
Returns the UIElementController associated with the given id, or null if no such controller is currently attached to the driver.
inherited
getNode(Object? key) → FocusNode?
Returns the FocusNode associated with the provided key, or null if no such node is attached.
inherited
init() → Future<void>
Initializes the UI driver.
initNativeModule() → Future<void>
Initializes the native module.
inherited
initScriptingCapability() → Future<void>
Initializes the scripting capability.
inherited
invokeNativeMethod<T>(String method, [dynamic arguments]) → Future<T?>
Invokes a native method.
inherited
isWidgetReady(String viewTag) → bool
Check if a widget is ready to be displayed.
inherited
linkDriver(UIDriver driver) → void
Links a UIDriver instance to this holder.
inherited
logCritical(dynamic message, [Object? exception, StackTrace? stackTrace]) → void
Logs a critical error message.
inherited
logDebug(dynamic message, [Object? exception, StackTrace? stackTrace]) → void
Logs a debug message.
inherited
logError(dynamic message, [Object? exception, StackTrace? stackTrace]) → void
Logs an error message.
inherited
logInfo(dynamic message, [Object? exception, StackTrace? stackTrace]) → void
Logs an informational message.
inherited
logVerbose(dynamic message, [Object? exception, StackTrace? stackTrace]) → void
Logs a verbose message.
inherited
logWarning(dynamic message, [Object? exception, StackTrace? stackTrace]) → void
Logs a warning message.
inherited
nextFocus(String nodeId) → bool
Moves the focus to the next focusable node in the traversal order relative to the node identified by nodeId.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyWidgetDisplayStateChanged(String viewTag, int state) → void
Notify the driver that the display state of a widget has changed.
inherited
prepareLayout(Map<String, dynamic> json) → Future<DuitView?>
Prepares and validates a layout configuration from a JSON-like map, returning a DuitView instance.
inherited
preparePayload(Iterable<ActionDependency> dependencies) → Map<String, dynamic>
Prepares and returns a payload map from the provided dependencies to be sent along with a ServerAction execution.
inherited
preparePayloadWithDataHash(Iterable<ActionDependency> dependencies) → (Map<String, dynamic>, int)
Save as preparePayload, but also calculate a hash of the data.
inherited
previousFocus(String nodeId) → bool
Moves the focus to the previous focusable node in the traversal order relative to the node identified by nodeId.
inherited
releaseResources() → void
Called to clean up any external resources, subscriptions, or handlers typically when a delegate is being disposed of or detached. Implementations should ensure all open streams or event sources are closed.
inherited
request(String url, Map<String, dynamic> meta, Map<String, dynamic> body) → Future<Map<String, dynamic>?>
Sends a request to the server.
inherited
requestFocus(String nodeId) → void
Requests that the focus be moved to the FocusNode associated with the given nodeId.
inherited
resolveEvent(BuildContext context, dynamic eventData) → Future<void>
Handles and resolves an incoming eventData in the given context.
inherited
toString() → String
A string representation of this object.
inherited
unfocus(String nodeId, {UnfocusDisposition disposition = UnfocusDisposition.scope}) → void
Removes focus from the node identified by nodeId and optionally determines the disposition for how focus should be handled within the focus scope.
inherited
updateAttributes(String controllerId, Map<String, dynamic> json) → Future<void>
Updates the attributes (properties) of the UI element controller identified by controllerId.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited