attributes property

ViewAttribute attributes
getter/setter pair

Typed attributes object (view properties).

The attributes property holds the typed attributes object associated with the controller. It provides access to the view properties and allows manipulation of their values.

Implementation

abstract ViewAttribute attributes;