DefaultLogger class final
The DefaultLogger class provides a default logger implementation for the DUIT library.
It logs messages to the console if the app is running in debug mode.
- Implemented types
- Annotations
-
- @Deprecated("Will be removed in the next major release.")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
error(
String message, {dynamic error, StackTrace? stackTrace}) → void -
override
-
info(
String message) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
warn(
String message) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → DefaultLogger
-
The DefaultLogger singleton instance.
final